@@ -4,7 +4,10 @@ use utf8;
 package Acme::ಠ_ಠ;
 # ABSTRACT: send warnings with ಠ_ಠ
 {
-    $Acme::ಠ_ಠ::VERSION = '0.003';
+    $Acme::ಠ_ಠ::VERSION = '0.004';
+}
+BEGIN {
+    our $AUTHORITY = 'cpan:ETHER';
 }
 
 use Acme::LookOfDisapproval;
@@ -28,7 +31,7 @@ Acme::ಠ_ಠ - send warnings with ಠ_ಠ
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
